diff src/structs.h @ 31582:8bbc932fbd09 v9.0.1123

patch 9.0.1123: class function not implemented yet Commit: https://github.com/vim/vim/commit/6bafdd41cbf8c06bc00f19dcf4e1c8292460b4dd Author: Bram Moolenaar <Bram@vim.org> Date: Sun Jan 1 12:58:33 2023 +0000 patch 9.0.1123: class function not implemented yet Problem: Class function not implemented yet. Solution: Implement defining and calling a class function.
author Bram Moolenaar <Bram@vim.org>
date Sun, 01 Jan 2023 14:00:07 +0100
parents 67d9fbe516a3
children 0eb51cec2154
line wrap: on
line diff
--- a/src/structs.h
+++ b/src/structs.h
@@ -1493,9 +1493,9 @@ struct class_S
     ocmember_T	*class_class_members;	// allocated
     typval_T	*class_members_tv;	// allocated array of class member vals
 
-    // class methods: "static def SomeMethod()"
-    int		class_class_method_count;
-    ufunc_T	**class_class_methods;	// allocated
+    // class functions: "static def SomeMethod()"
+    int		class_class_function_count;
+    ufunc_T	**class_class_functions;	// allocated
 
     // object members: "this.varname"
     int		class_obj_member_count;